=========
Changelog
=========


v1.0.0a1 (2019-01-07)
=====================

Initial alpha release. No guarantees about backwards compatibility.

Supports lookup of organizations ("enheter") by organization number from
Enhetsregisteret.
